@@ -2,6 +2,7 @@
 from . import (
     directory,
     functional,
+    output,
     stream,
     subprocess,
     tasks)
@@ -10,6 +11,7 @@ from . import (
 __all__ = (
     "directory",
     "functional",
+    "output",
     "stream",
     "subprocess",
     "tasks")
