@@ -3,9 +3,10 @@
 from .collections import async_iterator, async_list, async_set
 from .decorators import async_property
 from .generator import AwaitableGenerator
-from .process import async_map
-from .utils import buffered, maybe_awaitable, maybe_coro, nested
-from . import exceptions, utils
+from .output import buffered, buffering, capturing
+from .process import async_map, threaded
+from .utils import maybe_awaitable, maybe_coro, nested
+from . import utils
 
 
 __all__ = (
@@ -16,8 +17,11 @@ __all__ = (
     "async_set",
     "AwaitableGenerator",
     "buffered",
-    "exceptions",
+    "buffering",
+    "capturing",
     "maybe_awaitable",
     "maybe_coro",
     "nested",
+    "output",
+    "threaded",
     "utils")
